# default compile script

set module [get_unix_variable LSB_JOBNAME]

echo "##### Beginning default script on module ${module}"

read_db ../gdb/${module}.gdb

link

if { [check_error -v] == 1} {
	echo "Error: link error running default.tcl on module ${module}"
	getproc
	exit 1
	}

getproc

########################################
# apply constraints

reset_design

set PERIOD 5.0

set_operating_conditions $TARGET_OPCON -library $TARGETLIB

set_wire_load_model -name $TARGET_WL
set_wire_load_mode top

# overconstrain by 20%
set default_clock_period [expr $PERIOD * 0.80]

# eighths = 1/8 of clock period
set eighths [expr $default_clock_period / 8.0]

set_driving_cell -library $TARGETLIB -lib_cell $INV1_CELLNAME -pin $INV1_OUTPUT_PIN [ all_inputs ]
set_load [ expr  4 * [ load_of ${TARGETLIB}/${INV1_CELLNAME}/${INV1_INPUT_PIN} ] ] [ all_inputs ]
set_load [ expr 20 * [ load_of ${TARGETLIB}/${INV1_CELLNAME}/${INV1_INPUT_PIN} ] ] [ all_outputs ]

# constrain combinational Mealy paths to 1/2 of period
create_clock -period $default_clock_period -name comb_virtual_clk
set_input_delay  [expr 1 * $eighths] -clock comb_virtual_clk [all_inputs]
set_output_delay [expr 3 * $eighths] -clock comb_virtual_clk [all_outputs]

getproc

# constrain flops
if { [get_ports "clk"] != {} } {
  echo "##### applying constraints to flops"

  # constrain flop -> flop path
  create_clock -period $default_clock_period clk
  remove_driving_cell [find port "clk"]
  set_load 0 [find port "clk"]

  create_clock -period $default_clock_period -name io_virtual_clk

  # constrain input -> flop path to 3/8 of period
  set_input_delay  [expr 5 * $eighths] -clock io_virtual_clk -add_delay [all_inputs]

  # constrain flop -> output path to 1/8 of period
  set_output_delay [expr 7 * $eighths] -clock io_virtual_clk -add_delay [all_outputs]

  set_false_path -from [find clock io_virtual_clk]   -to [find clock io_virtual_clk]
  set_false_path -from [find clock comb_virtual_clk] -to [find clock clk]
  set_false_path -from [find clock clk]              -to [find clock comb_virtual_clk]
  set_false_path -from [find clock io_virtual_clk]   -to [find clock comb_virtual_clk]
  set_false_path -from [find clock comb_virtual_clk] -to [find clock io_virtual_clk]

  remove_input_delay [find port "clk"]
}
getproc

########################################
# compile

if {[filter [find cell] "@is_mapped==false"] != {}} {
compile
}
getproc

########################################

set_dont_touch $current_design true

write -out ${module}.db
getproc

report_qor
getproc

report_constraint
getproc

exit
